Working with Data — linkml documentation

# Working with Data

Introduction to the key parts of LinkML that you need to know:

Contents:

- Working with Data
  - Conversion
  - Programmatic usage
- Data Validation
  - Validation of JSON documents
  - Validation of RDF triplestores using generated SPARQL
  - Future plans
- Working with RDF and LinkML
  - JSON-LD
  - ShEx
  - SHACL
  - OWL
- CSVs and Tabular Data
  - Conversion
  - On the fly denormalization
  - Inference of schemas from tabular data
- Python
  - Dataclasses
  - Use in programs
  - Loaders and dumpers